[![Build Status](https://travis-ci.com/DiamondLightSource/CrystalMatch.svg?branch=master)](https://travis-ci.com/DiamondLightSource/CrystalMatch)
[![Coverage Status](https://coveralls.io/repos/github/DiamondLightSource/CrystalMatch/badge.svg?branch=master)](https://coveralls.io/github/DiamondLightSource/CrystalMatch?branch=master)
[![PyPI version](https://badge.fury.io/py/CrystalMatch.svg)](https://badge.fury.io/py/CrystalMatch)
[![Downloads](https://pepy.tech/badge/crystalmatch)](https://pepy.tech/project/crystalmatch)

VMXi Crystal Image Matching Readme
==================================

Installation
---------
CrystalMatch requires python 2.7 and openCV version 2.4.10 which can be downloaded from:
* [OpenCV](https://opencv.org/releases.html)

Once OpenCV is there CrystalMatch can be installed by running:

```
pip install CrystalMatch
```
See [pip installation](https://pip.pypa.io/en/stable/installing/) if you don't have pip.

Background
----------
Details about the purpose of the VMXi Crystal Image Matching Program

* [The VMXi Beamline](https://github.com/DiamondLightSource/CrystalMatch/blob/master/docs/vmxi.md)
* [The Problem of Feature Tracking](https://github.com/DiamondLightSource/CrystalMatch/blob/master/docs/tracking.md)

User Guide
----------
This section is a guide for users of the application

* [The User Guide](https://github.com/DiamondLightSource/CrystalMatch/blob/master/docs/user_guide.md)

Developer Guide
---------------
This section serves as an introduction for developers who are interested in maintaining or extending the Diamond Light Source (DLS) VMXi beamline crystal image matching application. The documents should be read in order
 
* [Code Use Instructions](https://github.com/DiamondLightSource/CrystalMatch/blob/master/docs/setup.md)
* [The Solution](https://github.com/DiamondLightSource/CrystalMatch/blob/master/docs/solution.md)
